registerGooglePlayTransaction method

Future<Response<void>> registerGooglePlayTransaction({
  1. required String appUserId,
  2. required String xApiKey,
  3. required UserRegisterGooglePlayTransactionRequest userRegisterGooglePlayTransactionRequest,
  4. CancelToken? cancelToken,
  5. Map<String, dynamic>? headers,
  6. Map<String, dynamic>? extra,
  7. ValidateStatus? validateStatus,
  8. ProgressCallback? onSendProgress,
  9. ProgressCallback? onReceiveProgress,
})

Register Google Play Transaction Registers the mapping between a user and their Google Play purchaseToken.

Parameters:

  • appUserId - The app user id of the user.
  • xApiKey - The API key to authenticate with.
  • userRegisterGooglePlayTransactionRequest
  • cancelToken - A CancelToken that can be used to cancel the operation
  • headers - Can be used to add additional headers to the request
  • extras - Can be used to add flags to the request
  • validateStatus - A ValidateStatus callback that can be used to determine request success based on the HTTP status of the response
  • onSendProgress - A ProgressCallback that can be used to get the send progress
  • onReceiveProgress - A ProgressCallback that can be used to get the receive progress

Returns a Future Throws DioException if API call or serialization fails

Implementation

Future<Response<void>> registerGooglePlayTransaction({
  required String appUserId,
  required String xApiKey,
  required UserRegisterGooglePlayTransactionRequest userRegisterGooglePlayTransactionRequest,
  CancelToken? cancelToken,
  Map<String, dynamic>? headers,
  Map<String, dynamic>? extra,
  ValidateStatus? validateStatus,
  ProgressCallback? onSendProgress,
  ProgressCallback? onReceiveProgress,
}) async {
  final _path = r'/users/{app_user_id}/transactions/google-play'.replaceAll('{' r'app_user_id' '}', encodeQueryParameter(_serializers, appUserId, const FullType(String)).toString());
  final _options = Options(
    method: r'POST',
    headers: <String, dynamic>{
      r'x-api-key': xApiKey,
      ...?headers,
    },
    extra: <String, dynamic>{
      'secure': <Map<String, String>>[],
      ...?extra,
    },
    contentType: 'application/json',
    validateStatus: validateStatus,
  );

  dynamic _bodyData;

  try {
    const _type = FullType(UserRegisterGooglePlayTransactionRequest);
    _bodyData = _serializers.serialize(userRegisterGooglePlayTransactionRequest, specifiedType: _type);

  } catch(error, stackTrace) {
    throw DioException(
       requestOptions: _options.compose(
        _dio.options,
        _path,
      ),
      type: DioExceptionType.unknown,
      error: error,
      stackTrace: stackTrace,
    );
  }

  final _response = await _dio.request<Object>(
    _path,
    data: _bodyData,
    options: _options,
    cancelToken: cancelToken,
    onSendProgress: onSendProgress,
    onReceiveProgress: onReceiveProgress,
  );

  return _response;
}