AppStoreOfferCode class abstract

The offer code

Properties:

Annotations
  • @BuiltValue.new()

Constructors

AppStoreOfferCode([void updates(AppStoreOfferCodeBuilder b)])
factory

Properties

customerEligibilities → BuiltList<String>
The offer code customer eligibilities.
no setter
duration AppStoreOfferCodeDurationEnum
The offer code duration.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
The offer code id.
no setter
name String
The offer code name.
no setter
numberOfPeriods int
The offer code number of periods.
no setter
offerEligibility AppStoreOfferCodeOfferEligibilityEnum
The offer code offer eligibility.
no setter
offerMode AppStoreOfferCodeOfferModeEnum
The offer code offer mode.
no setter
prices → BuiltList<AppStorePrice>?
The offer code prices.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AppStoreOfferCodeBuilder)) AppStoreOfferCode
Rebuilds the instance.
inherited
toBuilder() AppStoreOfferCodeBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AppStoreOfferCode>
no setter