AppStoreOfferCodeOfferEligibilityEnum class

Inheritance
  • Object
  • EnumClass
  • AppStoreOfferCodeOfferEligibilityEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AppStoreOfferCodeOfferEligibilityEnum>
no setter
values → BuiltSet<AppStoreOfferCodeOfferEligibilityEnum>
no setter

Constants

REPLACE_INTRO_OFFERS → const AppStoreOfferCodeOfferEligibilityEnum
The offer code offer eligibility.
STACK_WITH_INTRO_OFFERS → const AppStoreOfferCodeOfferEligibilityEnum
The offer code offer eligibility.