AppStorePrice class abstract

The price

Properties:

Annotations
  • @BuiltValue.new()

Constructors

AppStorePrice([void updates(AppStorePriceBuilder b)])
factory

Properties

currency String
The price currency.
no setter
hashCode int
The hash code for this object.
no setterinherited
price String
The price amount.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
territory String
The price territory.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AppStorePriceBuilder)) AppStorePrice
Rebuilds the instance.
inherited
toBuilder() AppStorePriceBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AppStorePrice>
no setter