AppStoreSubscription class abstract

The subscription on the App Store

Properties:

Annotations
  • @BuiltValue.new()

Constructors

AppStoreSubscription([void updates(AppStoreSubscriptionBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The subscription id.
no setter
name String
The subscription name.
no setter
prices → BuiltList<AppStorePrice>
The prices of the subscription.
no setter
productId String
The product id.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionPeriod AppStoreSubscriptionSubscriptionPeriodEnum
The subscription period.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AppStoreSubscriptionBuilder)) AppStoreSubscription
Rebuilds the instance.
inherited
toBuilder() AppStoreSubscriptionBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AppStoreSubscription>
no setter