BasicReward class abstract
BasicReward
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- BasicReward([void updates(BasicRewardBuilder b)])
-
factory
Properties
- createdAt → DateTime
-
The created at of the reward
no setter
- description → String?
-
The description of the reward
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
The key of the reward
no setter
- metadata → JsonObject?
-
The metadata of the reward
no setter
- name → String
-
The name of the reward
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime?
-
The updated at of the reward
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(BasicRewardBuilder)) → BasicReward -
Rebuilds the instance.
inherited
-
toBuilder(
) → BasicRewardBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
BasicReward> -
no setter