rewards property
The rewards granted to the user claiming the code
Implementation
@BuiltValueField(wireName: r'rewards')
ReceiverRewards get rewards;
The rewards granted to the user claiming the code
@BuiltValueField(wireName: r'rewards')
ReceiverRewards get rewards;