CodeAffiliate class abstract

CodeAffiliate

Properties:

  • name - The affiliate name
  • logoUrl - The affiliate logo url
  • platforms - The affiliate social platforms
Annotations
  • @BuiltValue.new()

Constructors

CodeAffiliate([void updates(CodeAffiliateBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
logoUrl String?
The affiliate logo url
no setter
name String
The affiliate name
no setter
platforms → BuiltList<AffiliatePlatform>
The affiliate social platforms
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CodeAffiliateBuilder)) CodeAffiliate
Rebuilds the instance.
inherited
toBuilder() CodeAffiliateBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CodeAffiliate>
no setter