CodeEntity class abstract
The type-specific entity: the affiliate, the promo code, or the referral code owner.
Properties:
name- The affiliate namelogoUrl- The affiliate logo urlplatforms- The affiliate social platformslimit- The maximum number of times the code can be claimed (0 = unlimited)appUserId- The app user id of the referral code owner
- Annotations
-
- @BuiltValue.new()
Constructors
- CodeEntity([void updates(CodeEntityBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- oneOf → OneOf
-
One Of CodeAffiliate, CodePromoCode, CodeReferralUser
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(CodeEntityBuilder)) → CodeEntity -
Rebuilds the instance.
inherited
-
toBuilder(
) → CodeEntityBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
CodeEntity> -
no setter