CodePromoCode class abstract

CodePromoCode

Properties:

  • limit - The maximum number of times the code can be claimed (0 = unlimited)
Annotations
  • @BuiltValue.new()

Constructors

CodePromoCode([void updates(CodePromoCodeBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int
The maximum number of times the code can be claimed (0 = unlimited)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CodePromoCodeBuilder)) CodePromoCode
Rebuilds the instance.
inherited
toBuilder() CodePromoCodeBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CodePromoCode>
no setter