limit property
The maximum number of times the code can be claimed (0 = unlimited)
Implementation
@BuiltValueField(wireName: r'limit')
int get limit;
The maximum number of times the code can be claimed (0 = unlimited)
@BuiltValueField(wireName: r'limit')
int get limit;