GooglePlayPromoCodeReward class abstract

GooglePlayPromoCodeReward

Properties:

  • key - The key of the reward
  • name - The name of the reward
  • description - The description of the reward
  • metadata - The metadata of the reward
  • createdAt - The created at of the reward
  • updatedAt - The updated at of the reward
Annotations
  • @BuiltValue.new()

Constructors

GooglePlayPromoCodeReward([void updates(GooglePlayPromoCodeRewardBuilder b)])
factory

Properties

createdAt DateTime
The created at of the reward
no setter
description String?
The description of the reward
no setter
hashCode int
The hash code for this object.
no setterinherited
key String
The key of the reward
no setter
metadata → JsonObject?
The metadata of the reward
no setter
name String
The name of the reward
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
The updated at of the reward
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GooglePlayPromoCodeRewardBuilder)) GooglePlayPromoCodeReward
Rebuilds the instance.
inherited
toBuilder() GooglePlayPromoCodeRewardBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GooglePlayPromoCodeReward>
no setter