GooglePlayPromoCodeValue class abstract

GooglePlayPromoCodeValue

Properties:

  • value - The promo code value
  • expiresAt - The promo code value expiration date
Annotations
  • @BuiltValue.new()

Constructors

GooglePlayPromoCodeValue([void updates(GooglePlayPromoCodeValueBuilder b)])
factory

Properties

expiresAt DateTime
The promo code value expiration date
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The promo code value
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GooglePlayPromoCodeValueBuilder)) GooglePlayPromoCodeValue
Rebuilds the instance.
inherited
toBuilder() GooglePlayPromoCodeValueBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GooglePlayPromoCodeValue>
no setter