OfferCodeResponse class abstract

OfferCodeResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

OfferCodeResponse([void updates(OfferCodeResponseBuilder b)])
factory

Properties

data OfferCodeResponseData
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OfferCodeResponseBuilder)) OfferCodeResponse
Rebuilds the instance.
inherited
toBuilder() OfferCodeResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OfferCodeResponse>
no setter