OfferCodeValue class abstract

OfferCodeValue

Properties:

  • value - The offer code value
  • link - The offer code redeem link
  • expiresAt - The offer code value expiration date
Annotations
  • @BuiltValue.new()

Constructors

OfferCodeValue([void updates(OfferCodeValueBuilder b)])
factory

Properties

expiresAt DateTime
The offer code value expiration date
no setter
hashCode int
The hash code for this object.
no setterinherited
The offer code redeem link
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The offer code value
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OfferCodeValueBuilder)) OfferCodeValue
Rebuilds the instance.
inherited
toBuilder() OfferCodeValueBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OfferCodeValue>
no setter