ReceiverBasicReward class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- ReceiverBasicReward([void updates(ReceiverBasicRewardBuilder b)])
-
factory
Properties
- activation → ReceiverRewardActivation
-
no setter
- deactivation → ReceiverBasicRewardDeactivation
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- reward → BasicReward
-
The reward
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ReceiverBasicRewardBuilder)) → ReceiverBasicReward -
Rebuilds the instance.
inherited
-
toBuilder(
) → ReceiverBasicRewardBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ReceiverBasicReward> -
no setter