ReceiverBasicRewardDeactivation class abstract

When the reward deactivates for the receiver

Properties:

  • variant - The reward deactivates after a fixed interval
  • duration - The duration of the interval
  • period - The period of the interval
Annotations
  • @BuiltValue.new()

Properties

hashCode int
The hash code for this object.
no setterinherited
oneOf → OneOf
One Of ReceiverRewardIntervalDeactivation, ReceiverRewardNeverDeactivation
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReceiverBasicRewardDeactivationBuilder)) ReceiverBasicRewardDeactivation
Rebuilds the instance.
inherited
toBuilder() ReceiverBasicRewardDeactivationBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReceiverBasicRewardDeactivation>
no setter