ReceiverBasicRewardDeactivationPeriodEnum class

Inheritance
  • Object
  • EnumClass
  • ReceiverBasicRewardDeactivationPeriodEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReceiverBasicRewardDeactivationPeriodEnum>
no setter
values → BuiltSet<ReceiverBasicRewardDeactivationPeriodEnum>
no setter

Constants

days → const ReceiverBasicRewardDeactivationPeriodEnum
The period of the interval
months → const ReceiverBasicRewardDeactivationPeriodEnum
The period of the interval
years → const ReceiverBasicRewardDeactivationPeriodEnum
The period of the interval