ReceiverOfferCodeReward class abstract

ReceiverOfferCodeReward

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ReceiverOfferCodeReward([void updates(ReceiverOfferCodeRewardBuilder b)])
factory

Properties

activation ReceiverRewardClaimActivation
no setter
deactivation ReceiverBasicRewardDeactivation
no setter
hashCode int
The hash code for this object.
no setterinherited
reward OfferCodeReward
The reward
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReceiverOfferCodeRewardBuilder)) ReceiverOfferCodeReward
Rebuilds the instance.
inherited
toBuilder() ReceiverOfferCodeRewardBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReceiverOfferCodeReward>
no setter