ReceiverRewards class abstract

ReceiverRewards

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ReceiverRewards([void updates(ReceiverRewardsBuilder b)])
factory

Properties

basic → BuiltList<ReceiverBasicReward>
The basic rewards
no setter
credit → BuiltList<ReceiverCreditReward>
The credit rewards
no setter
googleplayPromoCode → BuiltList<ReceiverGooglePlayPromoCodeReward>
The Google Play promo code rewards
no setter
hashCode int
The hash code for this object.
no setterinherited
offerCode → BuiltList<ReceiverOfferCodeReward>
The offer code rewards
no setter
revenuecatEntitlement → BuiltList<ReceiverRevenueCatEntitlementReward>
The RevenueCat entitlement rewards
no setter
revenuecatOffering → BuiltList<ReceiverRevenueCatOfferingReward>
The RevenueCat offering rewards
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReceiverRewardsBuilder)) ReceiverRewards
Rebuilds the instance.
inherited
toBuilder() ReceiverRewardsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReceiverRewards>
no setter