ReferralProgramReceiverBasicRewardActivationVariantEnum class

Inheritance
  • Object
  • EnumClass
  • ReferralProgramReceiverBasicRewardActivationVariantEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

claim → const ReferralProgramReceiverBasicRewardActivationVariantEnum
The variant of the activation configuration
conversion → const ReferralProgramReceiverBasicRewardActivationVariantEnum
The variant of the activation configuration