ReferralProgramReceiverBasicRewardNeverDeactivation class abstract
ReferralProgramReceiverBasicRewardNeverDeactivation
Properties:
- variant - The variant of the deactivation configuration
- Annotations
-
- @BuiltValue.new()
Constructors
- ReferralProgramReceiverBasicRewardNeverDeactivation([void updates(ReferralProgramReceiverBasicRewardNeverDeactivationBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → ReferralProgramReceiverBasicRewardNeverDeactivationVariantEnum
-
The variant of the deactivation configuration
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ReferralProgramReceiverBasicRewardNeverDeactivationBuilder)) → ReferralProgramReceiverBasicRewardNeverDeactivation -
Rebuilds the instance.
inherited
-
toBuilder(
) → ReferralProgramReceiverBasicRewardNeverDeactivationBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ReferralProgramReceiverBasicRewardNeverDeactivation> -
no setter