ReferralProgramReceiverGooglePlayPromoCodeRewardActivationBuilder class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant ReferralProgramReceiverGooglePlayPromoCodeRewardActivationVariantEnum?
getter/setter pair

Methods

build() ReferralProgramReceiverGooglePlayPromoCodeRewardActivation
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(ReferralProgramReceiverGooglePlayPromoCodeRewardActivation other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(ReferralProgramReceiverGooglePlayPromoCodeRewardActivationBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited