ReferralProgramReceiverOfferCodeReward class abstract
ReferralProgramReceiverOfferCodeReward
Properties:
- reward - The reward
- activation - The activation configuration
- deactivation
- Annotations
-
- @BuiltValue.new()
Constructors
- ReferralProgramReceiverOfferCodeReward([void updates(ReferralProgramReceiverOfferCodeRewardBuilder b)])
-
factory
Properties
- activation → ReferralProgramReceiverOfferCodeRewardActivation
-
The activation configuration
no setter
- deactivation → ReferralProgramReceiverOfferCodeRewardDeactivation
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- reward → OfferCodeReward
-
The reward
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ReferralProgramReceiverOfferCodeRewardBuilder)) → ReferralProgramReceiverOfferCodeReward -
Rebuilds the instance.
inherited
-
toBuilder(
) → ReferralProgramReceiverOfferCodeRewardBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ReferralProgramReceiverOfferCodeReward> -
no setter