ReferralProgramReceiverOfferCodeRewardActivation class abstract

ReferralProgramReceiverOfferCodeRewardActivation

Properties:

  • variant - The variant of the activation configuration
Annotations
  • @BuiltValue.new()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant ReferralProgramReceiverOfferCodeRewardActivationVariantEnum
The variant of the activation configuration
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReferralProgramReceiverOfferCodeRewardActivationBuilder)) ReferralProgramReceiverOfferCodeRewardActivation
Rebuilds the instance.
inherited
toBuilder() ReferralProgramReceiverOfferCodeRewardActivationBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReferralProgramReceiverOfferCodeRewardActivation>
no setter