ReferralProgramReceiverOfferCodeRewardDeactivation class abstract
The deactivation configuration
Properties:
variant- The variant of the deactivation configurationduration- The duration of the deactivation configurationperiod- The period of the deactivation configuration
- Annotations
-
- @BuiltValue.new()
Constructors
- ReferralProgramReceiverOfferCodeRewardDeactivation([void updates(ReferralProgramReceiverOfferCodeRewardDeactivationBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- oneOf → OneOf
-
One Of ReferralProgramReceiverOfferCodeRewardIntervalDeactivation, ReferralProgramReceiverOfferCodeRewardNeverDeactivation
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ReferralProgramReceiverOfferCodeRewardDeactivationBuilder)) → ReferralProgramReceiverOfferCodeRewardDeactivation -
Rebuilds the instance.
inherited
-
toBuilder(
) → ReferralProgramReceiverOfferCodeRewardDeactivationBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ReferralProgramReceiverOfferCodeRewardDeactivation> -
no setter