ReferralProgramReceiverRewards class abstract

ReferralProgramReceiverRewards

Properties:

Annotations
  • @BuiltValue.new()

Properties

basic → BuiltList<ReferralProgramReceiverBasicReward>
The program basic rewards
no setter
credit → BuiltList<ReferralProgramReceiverCreditReward>
The program credit rewards
no setter
googleplayPromoCode → BuiltList<ReferralProgramReceiverGooglePlayPromoCodeReward>
The program Google Play promo code rewards
no setter
hashCode int
The hash code for this object.
no setterinherited
offerCode → BuiltList<ReferralProgramReceiverOfferCodeReward>
The program offer code rewards
no setter
revenuecatEntitlement → BuiltList<ReferralProgramReceiverRevenueCatEntitlementReward>
The program RevenueCat entitlement rewards
no setter
revenuecatOffering → BuiltList<ReferralProgramReceiverRevenueCatOfferingReward>
The program RevenueCat offering rewards
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReferralProgramReceiverRewardsBuilder)) ReferralProgramReceiverRewards
Rebuilds the instance.
inherited
toBuilder() ReferralProgramReceiverRewardsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReferralProgramReceiverRewards>
no setter