ReferralProgramSenderBasicReward class abstract

ReferralProgramSenderBasicReward

Properties:

Annotations
  • @BuiltValue.new()

Properties

activation ReferralProgramSenderBasicRewardActivation
The activation configuration
no setter
deactivation ReferralProgramSenderBasicRewardDeactivation
no setter
hashCode int
The hash code for this object.
no setterinherited
reward BasicReward
The reward
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReferralProgramSenderBasicRewardBuilder)) ReferralProgramSenderBasicReward
Rebuilds the instance.
inherited
toBuilder() ReferralProgramSenderBasicRewardBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReferralProgramSenderBasicReward>
no setter