ReferralProgramSenderBasicRewardIntervalDeactivation class abstract

ReferralProgramSenderBasicRewardIntervalDeactivation

Properties:

  • variant - The variant of the deactivation configuration
  • duration - The duration of the deactivation configuration
  • period - The period of the deactivation configuration
Annotations
  • @BuiltValue.new()

Properties

duration int
The duration of the deactivation configuration
no setter
hashCode int
The hash code for this object.
no setterinherited
period ReferralProgramSenderBasicRewardIntervalDeactivationPeriodEnum
The period of the deactivation configuration
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant ReferralProgramSenderBasicRewardIntervalDeactivationVariantEnum
The variant of the deactivation configuration
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReferralProgramSenderBasicRewardIntervalDeactivationBuilder)) ReferralProgramSenderBasicRewardIntervalDeactivation
Rebuilds the instance.
inherited
toBuilder() ReferralProgramSenderBasicRewardIntervalDeactivationBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReferralProgramSenderBasicRewardIntervalDeactivation>
no setter