ReferralProgramSenderOfferCodeRewardActivation class abstract

ReferralProgramSenderOfferCodeRewardActivation

Properties:

  • variant - The variant of the activation configuration
  • amount - The amount of the activation configuration
  • limit - The limit of the activation configuration
Annotations
  • @BuiltValue.new()

Properties

amount int
The amount of the activation configuration
no setter
hashCode int
The hash code for this object.
no setterinherited
limit int
The limit of the activation configuration
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant ReferralProgramSenderOfferCodeRewardActivationVariantEnum
The variant of the activation configuration
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReferralProgramSenderOfferCodeRewardActivationBuilder)) ReferralProgramSenderOfferCodeRewardActivation
Rebuilds the instance.
inherited
toBuilder() ReferralProgramSenderOfferCodeRewardActivationBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReferralProgramSenderOfferCodeRewardActivation>
no setter