ReferralProgramSenderOfferCodeRewardDeactivation class abstract
The deactivation configuration
Properties:
variant- The variant of the deactivation configurationduration- The duration of the deactivation configurationperiod- The period of the deactivation configuration
- Annotations
-
- @BuiltValue.new()
Constructors
- ReferralProgramSenderOfferCodeRewardDeactivation([void updates(ReferralProgramSenderOfferCodeRewardDeactivationBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- oneOf → OneOf
-
One Of ReferralProgramSenderOfferCodeRewardIntervalDeactivation, ReferralProgramSenderOfferCodeRewardNeverDeactivation
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ReferralProgramSenderOfferCodeRewardDeactivationBuilder)) → ReferralProgramSenderOfferCodeRewardDeactivation -
Rebuilds the instance.
inherited
-
toBuilder(
) → ReferralProgramSenderOfferCodeRewardDeactivationBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ReferralProgramSenderOfferCodeRewardDeactivation> -
no setter