User class abstract

User

Properties:

  • appUserId - The unique identifier of the user in your app.
  • referralCode - The referral code of the user.
  • referralCodeLink - The referral code link of the user.
  • isTrial - Whether the user is a trial user.
  • isPremium - Whether the user is a premium user.
  • firstSeenAt - The date when the user was first seen at.
  • lastSeenAt - The date when the user was last seen at. Deprecated, always returns null and will be removed in the future.
  • metadata - The metadata of the user.
  • stripeCustomerId - The unique identifier of the user in Stripe.
  • claimCodeEligibility - The claim code eligibility of the user.
  • referredBy - The referred by object of the user.
  • stats - The stats of the user.
  • rewards - The rewards of the user.
  • referralProgram - The program of the user.
  • affiliate - The affiliate this user was recruited into on this app, or null if they are not one.
Annotations
  • @BuiltValue.new()

Constructors

User([void updates(UserBuilder b)])
factory

Properties

affiliate UserAffiliate?
The affiliate this user was recruited into on this app, or null if they are not one.
no setter
appUserId String
The unique identifier of the user in your app.
no setter
claimCodeEligibility UserClaimCodeEligibility
The claim code eligibility of the user.
no setter
firstSeenAt DateTime?
The date when the user was first seen at.
no setter
hashCode int
The hash code for this object.
no setterinherited
isPremium bool?
Whether the user is a premium user.
no setter
isTrial bool?
Whether the user is a trial user.
no setter
lastSeenAt DateTime?
The date when the user was last seen at. Deprecated, always returns null and will be removed in the future.
no setter
metadata → JsonObject?
The metadata of the user.
no setter
referralCode String?
The referral code of the user.
no setter
The referral code link of the user.
no setter
referralProgram ReferralProgram?
The program of the user.
no setter
referredBy UserReferredBy?
The referred by object of the user.
no setter
rewards UserRewards
The rewards of the user.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats UserStats
The stats of the user.
no setter
stripeCustomerId String?
The unique identifier of the user in Stripe.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserBuilder)) User
Rebuilds the instance.
inherited
toBuilder() UserBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<User>
no setter