affiliate property

  1. @BuiltValueField.new(wireName: r'affiliate')
UserAffiliate? get affiliate

The affiliate this user was recruited into on this app, or null if they are not one.

Implementation

@BuiltValueField(wireName: r'affiliate')
UserAffiliate? get affiliate;