UserAffiliateApplyLinkRequest class abstract

UserAffiliateApplyLinkRequest

Properties:

  • groupSlug - The affiliate group to apply to. Omit to link to the app's default group.
Annotations
  • @BuiltValue.new()

Properties

groupSlug String?
The affiliate group to apply to. Omit to link to the app's default group.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserAffiliateApplyLinkRequestBuilder)) UserAffiliateApplyLinkRequest
Rebuilds the instance.
inherited
toBuilder() UserAffiliateApplyLinkRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserAffiliateApplyLinkRequest>
no setter