codeLink property
The shareable link for the code. Null when the app has turned code links off for the affiliate group.
Implementation
@BuiltValueField(wireName: r'code_link')
String? get codeLink;
The shareable link for the code. Null when the app has turned code links off for the affiliate group.
@BuiltValueField(wireName: r'code_link')
String? get codeLink;