UserAffiliateStats class abstract

The affiliate's totals on this app.

Properties:

  • claims - The number of users who have claimed one of their codes.
  • conversions - The number of users who have converted to premium.
  • earnings - The commission accrued all-time, in USD cents. Gross and cumulative — not a balance, and not an amount available to withdraw.
Annotations
  • @BuiltValue.new()

Constructors

UserAffiliateStats([void updates(UserAffiliateStatsBuilder b)])
factory

Properties

claims int
The number of users who have claimed one of their codes.
no setter
conversions int
The number of users who have converted to premium.
no setter
earnings int
The commission accrued all-time, in USD cents. Gross and cumulative — not a balance, and not an amount available to withdraw.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserAffiliateStatsBuilder)) UserAffiliateStats
Rebuilds the instance.
inherited
toBuilder() UserAffiliateStatsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserAffiliateStats>
no setter