UserBasicRewardExpired class abstract
UserBasicRewardExpired
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- UserBasicRewardExpired([void updates(UserBasicRewardExpiredBuilder b)])
-
factory
Properties
- createdAt → DateTime
-
The created at of the reward
no setter
- expiredAt → DateTime
-
The expiration date of the reward
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- reward → BasicReward
-
The reward
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime?
-
The updated at of the reward
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(UserBasicRewardExpiredBuilder)) → UserBasicRewardExpired -
Rebuilds the instance.
inherited
-
toBuilder(
) → UserBasicRewardExpiredBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
UserBasicRewardExpired> -
no setter