UserClaimCodeRequest class abstract

UserClaimCodeRequest

Properties:

  • code - The code to claim. Can be affiliate, promo or referral code.
Annotations
  • @BuiltValue.new()

Constructors

UserClaimCodeRequest([void updates(UserClaimCodeRequestBuilder b)])
factory

Properties

code String
The code to claim. Can be affiliate, promo or referral code.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserClaimCodeRequestBuilder)) UserClaimCodeRequest
Rebuilds the instance.
inherited
toBuilder() UserClaimCodeRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserClaimCodeRequest>
no setter