UserClaimCodeResponseData class abstract
UserClaimCodeResponseData
Properties:
- rewardsGranted - The rewards granted to the user.
- user - The updated user.
- Annotations
-
- @BuiltValue.new()
Constructors
- UserClaimCodeResponseData([void updates(UserClaimCodeResponseDataBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rewardsGranted → UserRewardsGranted
-
The rewards granted to the user.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → User
-
The updated user.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(UserClaimCodeResponseDataBuilder)) → UserClaimCodeResponseData -
Rebuilds the instance.
inherited
-
toBuilder(
) → UserClaimCodeResponseDataBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
UserClaimCodeResponseData> -
no setter