UserGooglePlayPromoCodeRewardExpired class abstract

UserGooglePlayPromoCodeRewardExpired

Properties:

Annotations
  • @BuiltValue.new()

Properties

createdAt DateTime
The created at of the reward
no setter
expiredAt DateTime
The expiration date of the reward
no setter
hashCode int
The hash code for this object.
no setterinherited
reward GooglePlayPromoCodeReward
The reward
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
The updated at of the reward
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserGooglePlayPromoCodeRewardExpiredBuilder)) UserGooglePlayPromoCodeRewardExpired
Rebuilds the instance.
inherited
toBuilder() UserGooglePlayPromoCodeRewardExpiredBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserGooglePlayPromoCodeRewardExpired>
no setter