UserGrantRewardRequest class abstract

UserGrantRewardRequest

Properties:

  • key - The key of the reward to grant
  • operationId - An optional operation id that ensures the same operation won't be performed again
Annotations
  • @BuiltValue.new()

Constructors

UserGrantRewardRequest([void updates(UserGrantRewardRequestBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
The key of the reward to grant
no setter
operationId String?
An optional operation id that ensures the same operation won't be performed again
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserGrantRewardRequestBuilder)) UserGrantRewardRequest
Rebuilds the instance.
inherited
toBuilder() UserGrantRewardRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserGrantRewardRequest>
no setter