UserGrantRewardResponseData class abstract

UserGrantRewardResponseData

Properties:

Annotations
  • @BuiltValue.new()

Constructors

UserGrantRewardResponseData([void updates(UserGrantRewardResponseDataBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
rewardsGranted UserRewardsGranted
The rewards granted to the user.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user User
The updated user.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserGrantRewardResponseDataBuilder)) UserGrantRewardResponseData
Rebuilds the instance.
inherited
toBuilder() UserGrantRewardResponseDataBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserGrantRewardResponseData>
no setter