UserOfferCodeRewardActiveBuilder class

Properties

createdAt DateTime?
getter/setter pair
expiresAt DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
reward OfferCodeRewardBuilder
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
getter/setter pair
value OfferCodeValueBuilder
getter/setter pair

Methods

build() UserOfferCodeRewardActive
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(UserOfferCodeRewardActive other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(UserOfferCodeRewardActiveBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited