UserRegisterAppStoreTransactionRequest class abstract

UserRegisterAppStoreTransactionRequest

Properties:

Annotations
  • @BuiltValue.new()

Properties

appAccountToken String?
StoreKit 2 appAccountToken UUID.
no setter
hashCode int
The hash code for this object.
no setterinherited
originalTransactionId String
Apple's originalTransactionId from StoreKit.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserRegisterAppStoreTransactionRequestBuilder)) UserRegisterAppStoreTransactionRequest
Rebuilds the instance.
inherited
toBuilder() UserRegisterAppStoreTransactionRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserRegisterAppStoreTransactionRequest>
no setter