UserRegisterGooglePlayTransactionRequest class abstract

UserRegisterGooglePlayTransactionRequest

Properties:

Annotations
  • @BuiltValue.new()

Properties

hashCode int
The hash code for this object.
no setterinherited
obfuscatedExternalAccountId String?
Set in BillingFlowParams.setObfuscatedAccountId() — used for better matching.
no setter
purchaseToken String
Google Play's purchaseToken from the purchase flow.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserRegisterGooglePlayTransactionRequestBuilder)) UserRegisterGooglePlayTransactionRequest
Rebuilds the instance.
inherited
toBuilder() UserRegisterGooglePlayTransactionRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserRegisterGooglePlayTransactionRequest>
no setter