UserResponseData class abstract

UserResponseData

Properties:

Annotations
  • @BuiltValue.new()

Constructors

UserResponseData([void updates(UserResponseDataBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user User
The user
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserResponseDataBuilder)) UserResponseData
Rebuilds the instance.
inherited
toBuilder() UserResponseDataBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserResponseData>
no setter