UserRewards class abstract

UserRewards

Properties:

  • active - The referral user active rewards
  • expired - The referral user expired rewards
Annotations
  • @BuiltValue.new()

Constructors

UserRewards([void updates(UserRewardsBuilder b)])
factory

Properties

active UserRewardsActive
The referral user active rewards
no setter
expired UserRewardsExpired
The referral user expired rewards
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserRewardsBuilder)) UserRewards
Rebuilds the instance.
inherited
toBuilder() UserRewardsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserRewards>
no setter