UserStats class abstract

The stats of the user.

Properties:

  • claims - The number of users who have claimed the referral code.
  • conversions - The number of users who have converted to premium.
  • churns - The number of users who have churned.
Annotations
  • @BuiltValue.new()

Constructors

UserStats([void updates(UserStatsBuilder b)])
factory

Properties

churns int
The number of users who have churned.
no setter
claims int
The number of users who have claimed the referral code.
no setter
conversions int
The number of users who have converted to premium.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserStatsBuilder)) UserStats
Rebuilds the instance.
inherited
toBuilder() UserStatsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserStats>
no setter