claims property
The number of users who have claimed the referral code.
Implementation
@BuiltValueField(wireName: r'claims')
int get claims;
The number of users who have claimed the referral code.
@BuiltValueField(wireName: r'claims')
int get claims;