conversions property
The number of users who have converted to premium.
Implementation
@BuiltValueField(wireName: r'conversions')
int get conversions;
The number of users who have converted to premium.
@BuiltValueField(wireName: r'conversions')
int get conversions;