UserWithdrawCreditsRequest class abstract

UserWithdrawCreditsRequest

Properties:

  • key - The key of the credit reward to withdraw
  • amount - The amount of credits to withdraw
  • operationId - An optional operation id that ensures the same operation won't be performed again
Annotations
  • @BuiltValue.new()

Constructors

UserWithdrawCreditsRequest([void updates(UserWithdrawCreditsRequestBuilder b)])
factory

Properties

amount int
The amount of credits to withdraw
no setter
hashCode int
The hash code for this object.
no setterinherited
key String
The key of the credit reward to withdraw
no setter
operationId String?
An optional operation id that ensures the same operation won't be performed again
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(UserWithdrawCreditsRequestBuilder)) UserWithdrawCreditsRequest
Rebuilds the instance.
inherited
toBuilder() UserWithdrawCreditsRequestBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<UserWithdrawCreditsRequest>
no setter