operationId property
An optional operation id that ensures the same operation won't be performed again
Implementation
@BuiltValueField(wireName: r'operation_id')
String? get operationId;
An optional operation id that ensures the same operation won't be performed again
@BuiltValueField(wireName: r'operation_id')
String? get operationId;