AppStoreApi class
Constructors
AppStoreApi (Dio _dio , Serializers _serializers )
const
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
getOfferCode ({required String offerCodeId , required String xApiKey , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<OfferCodeResponse > >
Get Offer Code
Get an offer code with subscription and prices by the offer code id. Deprecated: this endpoint is deprecated and will be removed in a future release; please migrate away from it.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited