ClaimActionsApi class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
claimCode({required String appUserId, required String xApiKey, required UserClaimCodeRequest userClaimCodeRequest, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<UserClaimCodeResponse>>
-
Claim Code
Claims a code for a user. Code can be affiliate, promo or referral code.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited