CodesApi class
Constructors
-
CodesApi(Dio _dio, Serializers _serializers)
-
const
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCode({required String code, required String xApiKey, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<CodeResponse>>
-
Get Code
Resolves a code to its type (affiliate, promo or referral) and returns the relevant data for that type. Requires no app user id.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited