RewardsActionsApi class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
grantReward ({required String appUserId , required String xApiKey , required UserGrantRewardRequest userGrantRewardRequest , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<UserGrantRewardResponse > >
Grant a Reward
Grants a reward for a user. Note 1: currently only granting of credit rewards is supported. Note 2: this endpoint is only accessible with a secret API key.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
withdrawCredits ({required String appUserId , required String xApiKey , required UserWithdrawCreditsRequest userWithdrawCreditsRequest , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<UserWithdrawCreditsResponse > >
Withdraw Credits
Withdraws credits from a user.