UsersApi class
Constructors
-
UsersApi(Dio _dio, Serializers _serializers)
-
const
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createOrUpdateUser({required String xApiKey, required UserCreateRequest userCreateRequest, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<UserResponse>>
-
Create or Update User
Create or update a user if already exists.
-
getUser({required String appUserId, required String xApiKey, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<UserResponse>>
-
Get User
Retrieves a user by their app user id.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
registerAppStoreTransaction({required String appUserId, required String xApiKey, required UserRegisterAppStoreTransactionRequest userRegisterAppStoreTransactionRequest, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<void>>
-
Register App Store Transaction
Registers the mapping between a user and their Apple originalTransactionId.
-
registerGooglePlayTransaction({required String appUserId, required String xApiKey, required UserRegisterGooglePlayTransactionRequest userRegisterGooglePlayTransactionRequest, CancelToken? cancelToken, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
→ Future<Response<void>>
-
Register Google Play Transaction
Registers the mapping between a user and their Google Play purchaseToken.
-
toString()
→ String
-
A string representation of this object.
inherited