AffiliateAnalyticsEntryStatusEnum class
- Inheritance
-
- Object
- EnumClass
- AffiliateAnalyticsEntryStatusEnum
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
→ String
-
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Constants
-
approved
→ const AffiliateAnalyticsEntryStatusEnum
-
The affiliate current standing with the project. Not always
approved: an affiliate is reported for what they did in the period, so one since banned or deactivated still appears alongside the metrics they earned.
-
archived
→ const AffiliateAnalyticsEntryStatusEnum
-
The affiliate current standing with the project. Not always
approved: an affiliate is reported for what they did in the period, so one since banned or deactivated still appears alongside the metrics they earned.
-
banned
→ const AffiliateAnalyticsEntryStatusEnum
-
The affiliate current standing with the project. Not always
approved: an affiliate is reported for what they did in the period, so one since banned or deactivated still appears alongside the metrics they earned.
-
deactivated
→ const AffiliateAnalyticsEntryStatusEnum
-
The affiliate current standing with the project. Not always
approved: an affiliate is reported for what they did in the period, so one since banned or deactivated still appears alongside the metrics they earned.
-
pending
→ const AffiliateAnalyticsEntryStatusEnum
-
The affiliate current standing with the project. Not always
approved: an affiliate is reported for what they did in the period, so one since banned or deactivated still appears alongside the metrics they earned.
-
rejected
→ const AffiliateAnalyticsEntryStatusEnum
-
The affiliate current standing with the project. Not always
approved: an affiliate is reported for what they did in the period, so one since banned or deactivated still appears alongside the metrics they earned.
-
withdrawn
→ const AffiliateAnalyticsEntryStatusEnum
-
The affiliate current standing with the project. Not always
approved: an affiliate is reported for what they did in the period, so one since banned or deactivated still appears alongside the metrics they earned.