AffiliatePlatform class abstract
AffiliatePlatform
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- AffiliatePlatform([void updates(AffiliatePlatformBuilder b)])
-
factory
Properties
- handle → String
-
The public handle/username on the platform
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → AffiliatePlatformTypeEnum
-
The platform type
no setter
- verified → bool
-
Whether ownership of the platform has been verified
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(AffiliatePlatformBuilder)) → AffiliatePlatform -
Rebuilds the instance.
inherited
-
toBuilder(
) → AffiliatePlatformBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
AffiliatePlatform> -
no setter