Code class abstract
Code
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- Code([void updates(CodeBuilder b)])
-
factory
Properties
- code → String
-
The code
no setter
- entity → CodeEntity
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Whether the code is active and can be claimed
no setter
- rewards → ReceiverRewards
-
The rewards granted to the user claiming the code
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → CodeTypeEnum
-
The resolved code type
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(CodeBuilder)) → Code -
Rebuilds the instance.
inherited
-
toBuilder(
) → CodeBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
Code> -
no setter