OfferCodeResponseData class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- OfferCodeResponseData([void updates(OfferCodeResponseDataBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- offerCode → AppStoreOfferCode
-
The offer code
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscription → AppStoreSubscription
-
The subscription
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(OfferCodeResponseDataBuilder)) → OfferCodeResponseData -
Rebuilds the instance.
inherited
-
toBuilder(
) → OfferCodeResponseDataBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
OfferCodeResponseData> -
no setter