OfferCodeReward class abstract
OfferCodeReward
Properties:
- key - The key of the reward
- offerCodeId - The offer code id
- offerCodeRefName - The offer code reference name that is set in the App Store Connect
- subscriptionProductId - The subscription product id of the offer code
- name - The name of the reward
- description - The description of the reward
- metadata - The metadata of the reward
- createdAt - The created at of the reward
- updatedAt - The updated at of the reward
- Annotations
-
- @BuiltValue.new()
Constructors
- OfferCodeReward([void updates(OfferCodeRewardBuilder b)])
-
factory
Properties
- createdAt → DateTime
-
The created at of the reward
no setter
- description → String?
-
The description of the reward
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
The key of the reward
no setter
- metadata → JsonObject?
-
The metadata of the reward
no setter
- name → String
-
The name of the reward
no setter
- offerCodeId → String
-
The offer code id
no setter
- offerCodeRefName → String
-
The offer code reference name that is set in the App Store Connect
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionProductId → String
-
The subscription product id of the offer code
no setter
- updatedAt → DateTime?
-
The updated at of the reward
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(OfferCodeRewardBuilder)) → OfferCodeReward -
Rebuilds the instance.
inherited
-
toBuilder(
) → OfferCodeRewardBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
OfferCodeReward> -
no setter