ReferralProgram class abstract
ReferralProgram
Properties:
- id - The program id
- name - The program name
- description - The program description
- metadata - The program metadata
- distributionPercentage - The program distribution percentage
- limit - The program limit
- rewards - The program rewards
- createdAt - The program created at
- updatedAt - The program updated at
- Annotations
-
- @BuiltValue.new()
Constructors
- ReferralProgram([void updates(ReferralProgramBuilder b)])
-
factory
Properties
- createdAt → DateTime
-
The program created at
no setter
- description → String?
-
The program description
no setter
- distributionPercentage → int
-
The program distribution percentage
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The program id
no setter
- limit → int
-
The program limit
no setter
- metadata → JsonObject?
-
The program metadata
no setter
- name → String
-
The program name
no setter
- rewards → ReferralProgramRewards
-
The program rewards
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime?
-
The program updated at
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ReferralProgramBuilder)) → ReferralProgram -
Rebuilds the instance.
inherited
-
toBuilder(
) → ReferralProgramBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ReferralProgram> -
no setter