ReferralProgramReceiverOfferCodeRewardIntervalDeactivation class abstract
ReferralProgramReceiverOfferCodeRewardIntervalDeactivation
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
Properties
- duration → int
-
The duration of the deactivation configuration
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- period → ReferralProgramReceiverOfferCodeRewardIntervalDeactivationPeriodEnum
-
The period of the deactivation configuration
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → ReferralProgramReceiverOfferCodeRewardIntervalDeactivationVariantEnum
-
The variant of the deactivation configuration
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ReferralProgramReceiverOfferCodeRewardIntervalDeactivationBuilder)) → ReferralProgramReceiverOfferCodeRewardIntervalDeactivation -
Rebuilds the instance.
inherited
-
toBuilder(
) → ReferralProgramReceiverOfferCodeRewardIntervalDeactivationBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ReferralProgramReceiverOfferCodeRewardIntervalDeactivation> -
no setter