UserAffiliateCode class abstract
A code the affiliate can promote on this app.
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- UserAffiliateCode([void updates(UserAffiliateCodeBuilder b)])
-
factory
Properties
- code → String
-
The affiliate code.
no setter
- codeLink → String?
-
The shareable link for the code. Null when the app has turned code links off for the affiliate group.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(UserAffiliateCodeBuilder)) → UserAffiliateCode -
Rebuilds the instance.
inherited
-
toBuilder(
) → UserAffiliateCodeBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
UserAffiliateCode> -
no setter