UserBasicRewardActive class abstract
UserBasicRewardActive
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- UserBasicRewardActive([void updates(UserBasicRewardActiveBuilder b)])
-
factory
Properties
- createdAt → DateTime
-
The created at of the reward
no setter
- expiresAt → DateTime?
-
The expiration date of the reward
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- reward → BasicReward
-
The reward
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime?
-
The updated at of the reward
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(UserBasicRewardActiveBuilder)) → UserBasicRewardActive -
Rebuilds the instance.
inherited
-
toBuilder(
) → UserBasicRewardActiveBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
UserBasicRewardActive> -
no setter