UserClaimCodeEligibility class abstract
User's eligibility to claim referral code.
Properties:
- eligible - The claim code eligibility flag.
- eligibleUntil - The claim code eligibility until date.
- Annotations
-
- @BuiltValue.new()
Constructors
- UserClaimCodeEligibility([void updates(UserClaimCodeEligibilityBuilder b)])
-
factory
Properties
- eligible → bool
-
The claim code eligibility flag.
no setter
- eligibleUntil → DateTime?
-
The claim code eligibility until date.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(UserClaimCodeEligibilityBuilder)) → UserClaimCodeEligibility -
Rebuilds the instance.
inherited
-
toBuilder(
) → UserClaimCodeEligibilityBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
UserClaimCodeEligibility> -
no setter