UserCreateRequest class abstract
UserCreateRequest
Properties:
- appUserId - The unique identifier of the referral user in your app.
- isTrial - Whether the user is a trial user.
- isPremium - Whether the user is a premium user.
- firstSeenAt - The date when the user was first seen at.
- lastSeenAt - The date when the user was last seen at. Deprecated and will be removed in the future.
- metadata - The metadata of the user.
- stripeCustomerId - The unique identifier of the user in Stripe.
- Annotations
-
- @BuiltValue.new()
Constructors
- UserCreateRequest([void updates(UserCreateRequestBuilder b)])
-
factory
Properties
- appUserId → String
-
The unique identifier of the referral user in your app.
no setter
- firstSeenAt → DateTime?
-
The date when the user was first seen at.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPremium → bool?
-
Whether the user is a premium user.
no setter
- isTrial → bool?
-
Whether the user is a trial user.
no setter
- lastSeenAt → DateTime?
-
The date when the user was last seen at. Deprecated and will be removed in the future.
no setter
- metadata → JsonObject?
-
The metadata of the user.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stripeCustomerId → String?
-
The unique identifier of the user in Stripe.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(UserCreateRequestBuilder)) → UserCreateRequest -
Rebuilds the instance.
inherited
-
toBuilder(
) → UserCreateRequestBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
UserCreateRequest> -
no setter