UserReferredBy class abstract
The referred by of the user.
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- UserReferredBy([void updates(UserReferredByBuilder b)])
-
factory
Properties
- code → String?
-
The code claimed by the user. Can be null if the code's entity has been deleted.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → UserReferredByTypeEnum
-
The type of the code. Can be one of "affiliate", "promo", or "referral".
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(UserReferredByBuilder)) → UserReferredBy -
Rebuilds the instance.
inherited
-
toBuilder(
) → UserReferredByBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
UserReferredBy> -
no setter